///////////////////////////////////////////////////////////////////////////////
// MenuCatcher
// By: Kamek (kamek@postalleague.com)
// For: xCharacters
//
// An actor that "catches" the default MenuPlayer and replaces it with our own.
///////////////////////////////////////////////////////////////////////////////
class MenuCatcher extends Info;

///////////////////////////////////////////////////////////////////////////////
// Public vars
///////////////////////////////////////////////////////////////////////////////
var() class<ShellMenuCW> DefaultMenuPlayer;
var() class<ShellMenuCW> MyMenuPlayer;

///////////////////////////////////////////////////////////////////////////////
// Internal
///////////////////////////////////////////////////////////////////////////////
var PlayerController PlayerLocal;
var ShellRootWindow LocalRoot;
var MenuPlayerX MyMenu;
/*
var bool bGotCustomsYet;
var xCharsPawn.HeadInfo SomeHead;
var array<xCharsPawn.HeadInfo> DownloadedHeads;
var array<xCharsPawn.BodyInfo> DownloadedBodies;
*/
///////////////////////////////////////////////////////////////////////////////
// Replication
///////////////////////////////////////////////////////////////////////////////
replication
{
	reliable if (Role == ROLE_Authority)
		ClientResetPawnClasses, ClientAddPawnClass/*, ClientAddHeadInfo, ClientAddBodyInfo*/;

	reliable if (Role < ROLE_Authority)
		ServerRequestRoster/*, ServerRequestCustomOptions*/;
}
/*
///////////////////////////////////////////////////////////////////////////////
// PopulateCustomOptions
// MenuPlayerX calls this to add in all the "custom" head and body skins.
///////////////////////////////////////////////////////////////////////////////
simulated function PopulateCustomOptions(MenuPlayerX Menu)
{
	local int i;

	MyMenu = Menu;
	if (!bGotCustomsYet)
		ServerRequestCustomOptions();
	else
	{
		for (i=0; i<DownloadedHeads.Length; i++)
			AddHeadToMenu(DownloadedHeads[i]);

		for (i=0; i<DownloadedBodies.Length; i++)
			AddBodyToMenu(DownloadedBodies[i]);
	}
}

///////////////////////////////////////////////////////////////////////////////
// ServerRequestCustomOptions
// Server goes through the list of available heads/bodies and sends them.
///////////////////////////////////////////////////////////////////////////////
function ServerRequestCustomOptions()
{
	local int i;

	for (i=0; i<class'xCharsPawn'.Default.CustomHeads.Length; i++)
		ClientAddHeadInfo(class'xCharsPawn'.Default.CustomHeads[i]);

	for (i=0; i<class'xCharsPawn'.Default.CustomBodies.Length; i++)
		ClientAddBodyInfo(class'xCharsPawn'.Default.CustomBodies[i]);
}

///////////////////////////////////////////////////////////////////////////////
// ClientAddHeadInfo
// Adds the head to the list.
///////////////////////////////////////////////////////////////////////////////
simulated function ClientAddHeadInfo(xCharsPawn.HeadInfo H)
{
	DownloadedHeads.Insert(DownloadedHeads.Length, 1);
	DownloadedHeads[DownloadedHeads.Length-1] = H;
	AddHeadToMenu(H);
}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
simulated function AddHeadToMenu(xCharsPawn.HeadInfo H)
{
	if (MyMenu != None)
		MyMenu.AddHeadInfo(H);
}

///////////////////////////////////////////////////////////////////////////////
// ClientAddBodyInfo
// Adds the body to the list.
///////////////////////////////////////////////////////////////////////////////
simulated function ClientAddBodyInfo(xCharsPawn.BodyInfo B)
{
	DownloadedBodies.Insert(DownloadedBodies.Length, 1);
	DownloadedBodies[DownloadedBodies.Length-1] = B;
	AddBodyToMenu(B);
}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
simulated function AddBodyToMenu(xCharsPawn.BodyInfo B)
{
	if (MyMenu != None)
		MyMenu.AddBodyInfo(B);
}
*/
///////////////////////////////////////////////////////////////////////////////
// ServerRequestRoster
///////////////////////////////////////////////////////////////////////////////
function ServerRequestRoster()
{
	if (Level.Game != None
		&& MpGameReplicationInfo(Level.Game.GameReplicationInfo) != None
		&& xCharsHugeRoster(MpGameReplicationInfo(Level.Game.GameReplicationInfo).DMRoster) != None)
	{
		xCharsHugeRoster(MpGameReplicationInfo(Level.Game.GameReplicationInfo).DMRoster).SendRoster(Self);
	}
}

///////////////////////////////////////////////////////////////////////////////
// ResetPawnClasses
// Hack for replicating the dynamic array PawnClasses
///////////////////////////////////////////////////////////////////////////////
simulated function ClientResetPawnClasses(xCharsHugeRoster MyRoster)
{
//	log("Entered ClientResetPawnClasses("$MyRoster$")");
	if (Role < ROLE_Authority && MyRoster != None && MyRoster.PawnClasses.Length > 0)
	{
//		log("Received ResetPawnClasses, resetting");
		MyRoster.PawnClasses.Remove(0, MyRoster.PawnClasses.Length);
	}
}

///////////////////////////////////////////////////////////////////////////////
// AddPawnClass
// Hack for replicating the dynamic array PawnClasses
///////////////////////////////////////////////////////////////////////////////
simulated function ClientAddPawnClass(xCharsHugeRoster MyRoster, class<MpPawn> pclass)
{
//	log("Entered ClientAddPawnClass("$MyRoster$","@pclass$")");
	if (Role < ROLE_Authority && MyRoster != None)
	{
		MyRoster.PawnClasses.Insert(MyRoster.PawnClasses.Length, 1);
		MyRoster.PawnClasses[MyRoster.PawnClasses.Length-1] = pclass;
//		log("PawnClass["$MyRoster.PawnClasses.Length-1$"] ="@MyRoster.PawnClasses[MyRoster.PawnClasses.Length-1]);
	}
}

///////////////////////////////////////////////////////////////////////////////
// GetLocalPlayer
// Sets PlayerLocal to the local PlayerController.
///////////////////////////////////////////////////////////////////////////////
simulated function GetLocalPlayer()
{
	local PlayerController C;

	// Don't bother on server side
	if (Level.NetMode != NM_DedicatedServer)
	{
		foreach DynamicActors(class 'PlayerController', C)
    		if (Viewport(C.Player) != None)
    		{
    			PlayerLocal = C;
      			break;
      		}
	}
}

///////////////////////////////////////////////////////////////////////////////
// PostNetBeginPlay
// Get local player and root menu.
///////////////////////////////////////////////////////////////////////////////
simulated event PostNetBeginPlay()
{
	if (Role < ROLE_Authority)
		ServerRequestRoster();

	GetLocalPlayer();
	if (PlayerLocal != None
		&& ShellRootWindow(PlayerLocal.Player.InteractionMaster.BaseMenu) != None)
		LocalRoot = ShellRootWindow(PlayerLocal.Player.InteractionMaster.BaseMenu);
}

///////////////////////////////////////////////////////////////////////////////
// Tick
// Constantly check to see if the player has entered the player config window.
// If so, reject it and show our config window instead.
///////////////////////////////////////////////////////////////////////////////
simulated event Tick(float Delta)
{
	// Don't care on server side
	if (Level.NetMode == NM_DedicatedServer || LocalRoot == None)
		return;

	// If they're in the player config menu, reject it
	if (LocalRoot.MyMenu != None && LocalRoot.MyMenu.Class == DefaultMenuPlayer)
	{
		LocalRoot.GoBack();					// Ditch the window
		LocalRoot.JumpToMenu(MyMenuPlayer);	// Open our window
	}
}

///////////////////////////////////////////////////////////////////////////////
// Default properties
///////////////////////////////////////////////////////////////////////////////

defaultproperties
{
     DefaultMenuPlayer=Class'Shell.MenuPlayer'
     MyMenuPlayer=Class'xMaDHeAdZChars.MenuPlayerX'
     RemoteRole=ROLE_SimulatedProxy
}
