///////////////////////////////////////////////////////////////////////////////
// MenuPlayerX
// By: Kamek (kamek@postalleague.com)
// For: xCharacters
//
// xCharacters player setup menu.
///////////////////////////////////////////////////////////////////////////////
class MenuPlayerX extends MenuPlayer;

///////////////////////////////////////////////////////////////////////////////
// Localized
///////////////////////////////////////////////////////////////////////////////
var localized string HeadText;
var localized string HeadHelp;

var localized string BodyText;
var localized string BodyHelp;

///////////////////////////////////////////////////////////////////////////////
// Internal
///////////////////////////////////////////////////////////////////////////////
//var UWindowComboControl	HeadCombo;
//var UWindowComboControl	BodyCombo;
//var MenuCatcher MyCatcher;
//var array<xCharsPawn.HeadInfo> AvailableHeads;
//var array<xCharsPawn.BodyInfo> AvailableBodies;

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
function class<xCharsPawn> GetSelectedPawnClass()
{
	return xCharacterWindow(CharacterWindow).GetSelectedPawnClass();
}

///////////////////////////////////////////////////////////////////////////////
// Create menu contents
///////////////////////////////////////////////////////////////////////////////
function CreateMenuContents()
{
	local string str;

	Super(ShellMenuCW).CreateMenuContents();

	TitleAlign = TA_Center;
	ItemAlign = TA_Left;

	// This should never be called outside of an active game
	if (IsGameMenu())
		AddTitle(PlayerChangeText, TitleFont, TitleAlign);
	else
		AddTitle(PlayerSetupText, TitleFont, TitleAlign);

	if (IsGameMenu())
		NameBox = AddEditBox(NameChangeText, NameChangeHelp, ItemFont);
	else
		NameBox = AddEditBox(NameSetupText, NameSetupHelp, ItemFont);
	NameBox.EditBox.Font = F_Bold;

	if (IsGameMenu())
		CharacterCombo = AddComboBox(CharacterChangeText,	CharacterChangeHelp,	ItemFont);
	else
		CharacterCombo = AddComboBox(CharacterSetupText,	CharacterSetupHelp,		ItemFont);
	CharacterCombo.SetButtons(true);

	CharacterWindow = AddCharacterWindow(160);

	if (IsGameMenu())
	{
		if(GetPlayerOwner().GameReplicationInfo.bTeamGame)
			TeamCombo = AddComboBox(TeamChangeText, TeamChangeHelp, ItemFont);
	}
	else
		TeamCombo = AddComboBox(TeamSetupText, TeamSetupHelp, ItemFont);
	if (TeamCombo != None)
		TeamCombo.SetButtons(true);
/*
	HeadCombo = AddComboBox(HeadText, HeadHelp, ItemFont);
	HeadCombo.SetButtons(True);
	HeadCombo.HideWindow();

	BodyCombo = AddComboBox(BodyText, BodyHelp, ItemFont);
	BodyCombo.SetButtons(True);
	BodyCombo.HideWindow();
*/
	ConnectionCombo = AddComboBox(ConnectionText,	ConnectionHelp,	ItemFont);

	BackChoice = AddChoice(BackText, "", ItemFont, ItemAlign, true);

	// fill in space just so everything still lines up right during the game
	// otherwise the character's head goes behind the "Change Character" combo
	if (IsGameMenu())
	{
		if(!GetPlayerOwner().GameReplicationInfo.bTeamGame)
			AddItem(None, BackChoice.WinHeight);
		AddItem(None, BackChoice.WinHeight);
	}

	LoadValues();
	ResolutionChanged(Root.RealWidth, Root.RealHeight);
	bAllowChangedEvents = true;
}
/*
///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
function AddHeadInfo(xCharsPawn.HeadInfo H)
{
	local class<xCharsPawn> xCharsClass;

	AvailableHeads.Insert(AvailableHeads.Length, 1);
	AvailableHeads[AvailableHeads.Length-1] = H;
	HeadCombo.AddItem(H.Name);

	xCharsClass = GetSelectedPawnClass();
	if (xCharsClass != None
		&& xCharsClass.Default.bAllowCustomSkin
		&& xCharsClass.Default.DesiredHead.HeadTex == H.HeadTex
		&& xCharsClass.Default.DesiredHead.HeadMesh == H.HeadMesh)
		HeadCombo.SetSelectedIndex(AvailableHeads.Length-1);
}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
function AddBodyInfo(xCharsPawn.BodyInfo B)
{
	local class<xCharsPawn> xCharsClass;

	AvailableBodies.Insert(AvailableBodies.Length, 1);
	AvailableBodies[AvailableBodies.Length-1] = B;
	BodyCombo.AddItem(B.Name);

	xCharsClass = GetSelectedPawnClass();
	if (xCharsClass != None
		&& xCharsClass.Default.bAllowCustomSkin
		&& xCharsClass.Default.DesiredBody.BodyTex == B.BodyTex
		&& xCharsClass.Default.DesiredBody.BodyMesh == B.BodyMesh)
		BodyCombo.SetSelectedIndex(AvailableBodies.Length-1);
}

///////////////////////////////////////////////////////////////////////////////
// Load all values from ini files
///////////////////////////////////////////////////////////////////////////////
function LoadValues()
{
	Super.LoadValues();

	// Get a valid reference to the menu catcher
	foreach GetPlayerOwner().DynamicActors(class'MenuCatcher', MyCatcher)
		break;

	HeadCombo.Clear();
	BodyCombo.Clear();
	MyCatcher.PopulateCustomOptions(Self);
}
*/
///////////////////////////////////////////////////////////////////////////////
// Add character display item
///////////////////////////////////////////////////////////////////////////////
function CharacterWindow AddCharacterWindow(float Height)
{
	local CharacterWindow cw;
	local int i;

	// Add a child window for the message.
	cw = CharacterWindow(CreateWindow(class'xCharacterWindow', GetNextItemPosX(), GetNextItemPosY(), ItemMaxWidth, Height));

	AddItem(cw, Height + ItemSpacingY);
	return cw;
}

///////////////////////////////////////////////////////////////////////////////
// LoadTeamCharacters
// Same as super but adds HugeRoster functionality.
///////////////////////////////////////////////////////////////////////////////
function LoadTeamCharacters(TeamInfo DefaultTeam, string DefaultClassName)
{
	local string InitialClass;
	local MpTeamInfo myTeamInfo;
	local xCharsHugeRoster MyHugeRoster;
	local class<MpPawn> PawnClass;
	local int CharacterIndex, Num, i;

	InitialClass = GetPlayerOwner().ConsoleCommand("get" @ MultiPlayerClassPath);
	CharacterCombo.Clear();

	myTeamInfo = MpTeamInfo(DefaultTeam);
	if (xCharsHugeRoster(DefaultTeam) != None)
	{
		MyHugeRoster = xCharsHugeRoster(DefaultTeam);

		PawnClass = MyHugeRoster.PawnClasses[Num];
		while(PawnClass != None && i < 200)
		{
			CharacterCombo.AddItem(PawnClass.Default.MenuName, string(PawnClass));
			if(string(PawnClass) ~= DefaultClassName)
				CharacterIndex = Num;

			Num++;
			PawnClass = MyHugeRoster.PawnClasses[Num];
			i++;
		}
	}
	else
	{
		PawnClass = myTeamInfo.AllowedTeamMembers[Num];
		while(PawnClass != None && i < 200)
		{
			CharacterCombo.AddItem(PawnClass.Default.MenuName, string(PawnClass));
			if(string(PawnClass) ~= DefaultClassName)
				CharacterIndex = Num;

			Num++;
			PawnClass = myTeamInfo.AllowedTeamMembers[Num];
			i++;
		}
	}

	CharacterCombo.SetSelectedIndex(CharacterIndex);

	if(InitialClass != CharacterCombo.GetValue2())
		CharacterChanged();
}
/*
///////////////////////////////////////////////////////////////////////////////
// Handle notifications from controls
///////////////////////////////////////////////////////////////////////////////
function Notify(UWindowDialogControl C, byte E)
{
	Super.Notify(C, E);
	switch(E)
	{
		case DE_Change:
			switch (C)
			{
				case HeadCombo:
					HeadChanged();
					break;
				case BodyCombo:
					BodyChanged();
					break;
			}
			break;
	}
}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
function HeadChanged()
{
	local class<xCharsPawn> xCharsClass;

	xCharsClass = GetSelectedPawnClass();
	if (xCharsClass == None || !xCharsClass.Default.bAllowCustomSkin)
		return;

	xCharsClass.Default.DesiredHead = AvailableHeads[HeadCombo.GetSelectedIndex()];
	CharacterChanged();
}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
function BodyChanged()
{
	local class<xCharsPawn> xCharsClass;

	xCharsClass = GetSelectedPawnClass();
	if (xCharsClass == None || !xCharsClass.Default.bAllowCustomSkin)
		return;

	xCharsClass.Default.DesiredBody = AvailableBodies[BodyCombo.GetSelectedIndex()];
	CharacterChanged();
}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
singular function CharacterChanged()
{
	local class<xCharsPawn> xCharsClass;
	local int i;
	local int SelectedHead, SelectedBody;

	Super.CharacterChanged();

	xCharsClass = GetSelectedPawnClass();
	if (xCharsClass != None)
	{
		if (xCharsClass.Default.DesiredHead.HeadTex != None && xCharsClass.Default.DesiredBody.BodyTex != None)
			xCharacterWindow(CharacterWindow).SetHeadAndBodyInfo(xCharsClass.Default.DesiredHead, xCharsClass.Default.DesiredBody);

		if (xCharsClass.Default.bAllowCustomSkin)
		{
			HeadCombo.ShowWindow();
			BodyCombo.ShowWindow();

			SelectedHead = -1;
			SelectedBody = -1;

			for (i=0; i<AvailableHeads.Length; i++)
			{
//				if (AvailableHeads[i].HeadTex == xCharsClass.Default.DesiredHead.HeadTex
//					&& AvailableHeads[i].HeadMesh == xCharsClass.Default.DesiredHead.HeadMesh)
				if (AvailableHeads[i] == xCharsClass.Static.GetDesiredHead())
				{
					SelectedHead = i;
//					HeadCombo.SetSelectedIndex(i);
				}
			}

			for (i=0; i<AvailableBodies.Length; i++)
			{
				if (AvailableBodies[i].BodyTex == xCharsClass.Default.DesiredBody.BodyTex
					&& AvailableBodies[i].BodyMesh == xCharsClass.Default.DesiredBody.BodyMesh)
				{
					SelectedBody = i;
//					BodyCombo.SetSelectedIndex(i);
				}
			}

			if (SelectedHead != -1)
				HeadCombo.SetSelectedIndex(SelectedHead);

			if (SelectedBody != -1)
				BodyCombo.SetSelectedIndex(SelectedBody);
		}
		else
		{
			HeadCombo.HideWindow();
			BodyCombo.HideWindow();
		}
	}
}
*/
///////////////////////////////////////////////////////////////////////////////
// Default properties
///////////////////////////////////////////////////////////////////////////////

defaultproperties
{
     HeadText="Custom Head"
     HeadHelp="Choose a head skin for the Custom character."
     BodyText="Custom Body"
     BodyHelp="Choose a body skin for the Custom character."
     CharacterChangeText="Change xCharacter"
     CharacterChangeHelp="Change your xCharacter.  Your xCharacter won't change until the next time you die."
     PlayerChangeText="xCharacter Change"
     astrTextureDetailNames(0)="UltraLow"
     astrTextureDetailNames(1)="Low"
     astrTextureDetailNames(2)="Medium"
     astrTextureDetailNames(3)="High"
}
