///////////////////////////////////////////////////////////////////////////////
// MutHugeRoster
// By: Kamek (kamek@postalleague.com)
// For: xCharacters
//
// Mutator to replace the standard player setup menu with the xCharacters menu
///////////////////////////////////////////////////////////////////////////////
class MutHugeRoster extends Mutator;

var string XCPackage;

// Check for incoming players and show them the MOTD.
function bool CheckReplacement(Actor Other, out byte bSuperRelevant)
{
	local MenuCatcher MyDisplayer;

	// Spawn the MOTDDisplayer, which handles the work on the client side.
	if (PlayerController(Other) != None)
		MyDisplayer = Spawn(class'MenuCatcher', Other);

	return true;
}

//------------------------------------------------------------------------------
// Player start functions

//
// Grab the next option from a string.
//
function bool GrabOption( out string Options, out string Result )
{
	if( Left(Options,1)=="?" )
	{
		// Get result.
		Result = Mid(Options,1);
		if( InStr(Result,"?")>=0 )
			Result = Left( Result, InStr(Result,"?") );

		// Update options.
		Options = Mid(Options,1);
		if( InStr(Options,"?")>=0 )
			Options = Mid( Options, InStr(Options,"?") );
		else
			Options = "";

		return true;
	}
	else return false;
}

//
// Break up a key=value pair into its key and value.
//
function GetKeyValue( string Pair, out string Key, out string Value )
{
	if( InStr(Pair,"=")>=0 )
	{
		Key   = Left(Pair,InStr(Pair,"="));
		Value = Mid(Pair,InStr(Pair,"=")+1);
	}
	else
	{
		Key   = Pair;
		Value = "";
	}
}

/* ParseOption()
 Find an option in the options string and return it.
*/
function string ParseOption( string Options, string InKey )
{
	local string Pair, Key, Value;
	while( GrabOption( Options, Pair ) )
	{
		GetKeyValue( Pair, Key, Value );
		if( Key ~= InKey )
			return Value;
	}
	return "";
}

function ModifyLogin(out string Portal, out string Options)
{
	local string DesiredClass, NewClass;
	local int i;

        NewClass = "";
	DesiredClass = ParseOption(Options, "Class");
	
	if (!(Left(DesiredClass,len(XCPackage)) ~= XCPackage))
		NewClass = xCharsHugeRoster(MpGameReplicationInfo(Level.Game.GameReplicationInfo).DMRoster).RandomCharacter();

	if (NewClass == "")
		NewClass = DesiredClass;

	ReplaceText(Options, DesiredClass, NewClass);

	if ( NextMutator != None )
		NextMutator.ModifyLogin(Portal, Options);
}

///////////////////////////////////////////////////////////////////////////////
// Default properties
///////////////////////////////////////////////////////////////////////////////

defaultproperties
{
     XCPackage="xMaDHeAdZChars"
     FriendlyName="Huge Roster"
     Description="Allows huge deathmatch rosters for xCharacters. DO NOT ADD MANUALLY; this is done by the selected roster!"
}
