class xCharsHead extends MPHead;

// Animation status
var name AnimStatus;
var name AnimAction;			// use for replicating anims

replication
{
	reliable if (Role == ROLE_Authority && bNetDirty)
		AnimAction;

	reliable if (Role == ROLE_Authority)
		SetAnimAction;
}

///////////////////////////////////////////////////////////////////////////////
// Setup animations
///////////////////////////////////////////////////////////////////////////////
simulated function SetupAnims()
{
	// PlayAnim
	// LoopAnim
	// name Sequence, optional float Rate, optional float TweenTime, optional int Channel

	// Base channel gets base pose and is always at 100%
	PlayAnim('base', 1.0, 0.1, CHANNEL_BASE);

	// Use timer to blink eyes every so often
	bKillTalk = false;
	SetTimer(BLINK_TIME, false);
}

///////////////////////////////////////////////////////////////////////////////
// Play the eyes close animation, and turn off all blending
///////////////////////////////////////////////////////////////////////////////
simulated function PlayAnimDead()
{
	AnimBlendParams(CHANNEL_EMOTION, 0.0);
	AnimBlendParams(CHANNEL_MOUTH, 0.0);
	AnimBlendParams(CHANNEL_EYES, 0.0);
	AnimBlendParams(CHANNEL_BLINK, 0.0);
	LoopAnim('Dead');
}

///////////////////////////////////////////////////////////////////////////////
// Set the mood
///////////////////////////////////////////////////////////////////////////////
function SetMood(EMood moodNew, float amount)
	{
	amount = FClamp(amount, 0.0, 1.0);

	MyMood = moodNew;

	switch (moodNew)
		{
		case MOOD_Happy:
		case MOOD_Normal:
			SetAnimAction('MOOD_Normal');
			break;

		case MOOD_Paranoid:
		case MOOD_Sad:
		case MOOD_Scared:
			SetAnimAction('MOOD_Sad', amount);
			break;

		case MOOD_Angry:
		case MOOD_Combat:
			SetAnimAction('MOOD_Angry', amount);
			break;

		case MOOD_Puking:
			break;

		default:
			Log("SetMood(): Unrecognized mood!");
			break;
		}
	}

///////////////////////////////////////////////////////////////////////////////
// Talk for specified amount of time.
///////////////////////////////////////////////////////////////////////////////
function Talk(float fDuration)
{
	SetAnimAction('talking',, fDuration);
}

///////////////////////////////////////////////////////////////////////////////
// Yell for specified amount of time.
///////////////////////////////////////////////////////////////////////////////
function Yell(float fDuration)
{
	SetAnimAction('yelling',, fDuration);
}

///////////////////////////////////////////////////////////////////////////////
// Function that determines how to play all these specific animations.
// Needed complexity to work on remote clients (otherwise only the guy
// on his own machine could see his pawn animating like the following and
// no one elses.)
///////////////////////////////////////////////////////////////////////////////
simulated event SetAnimAction(name NewAction, optional float MoodAmount, optional float fDuration)
{
	log(self@"SetAnimAction to"@NewAction@"MoodAmount"@MoodAmount@"Duration"@fDuration);
	AnimAction = NewAction;

	if (NewAction == 'MOOD_Normal')
		AnimBlendParams(CHANNEL_EMOTION, 0);

	else if (NewAction == 'MOOD_Sad')
	{
		AnimBlendParams(CHANNEL_EMOTION, MoodAmount);
		LoopAnim('sad', 1.0, 0.1, CHANNEL_EMOTION);
	}

	else if (NewAction == 'MOOD_Angry')
	{
		AnimBlendParams(CHANNEL_EMOTION, MoodAmount);
		LoopAnim('angry', 1.0, 0.1, CHANNEL_EMOTION);
	}

	else if (NewAction == 'talking')
	{
		AnimBlendParams(CHANNEL_BLINK, 0.0);
		AnimBlendParams(CHANNEL_EYES, 0.0);
		// Loop the talking animation
		AnimBlendParams(CHANNEL_MOUTH, 1);
		LoopAnim('talk', 1.0, 0.1, CHANNEL_MOUTH);

		// Set timer to stop talking when the audio stops.  This is a ugly
		// because we're also using the timer to blink the eyes, but we'll
		// eventually switch to full lip-sync, so this is a temporary hack.
		SetTimer(fDuration, false);
		bKillTalk = true;
	}

	else if (NewAction == 'yelling')
	{
		AnimBlendParams(CHANNEL_BLINK, 0.0);
		AnimBlendParams(CHANNEL_EYES, 0.0);
		// Loop the talking animation
		AnimBlendParams(CHANNEL_MOUTH, 1);
		LoopAnim('yell', 1.0, 0.1, CHANNEL_MOUTH);

		// Set timer to stop talking when the audio stops.  This is a ugly
		// because we're also using the timer to blink the eyes, but we'll
		// eventually switch to full lip-sync, so this is a temporary hack.
		SetTimer(fDuration, false);
		bKillTalk = true;
	}

	else
	{
		log(self@"SetAnimAction: Unknown action"@NewAction);
	}
}

///////////////////////////////////////////////////////////////////////////////
// Time has expired
///////////////////////////////////////////////////////////////////////////////
simulated event Timer()
{
	local float lookamount, looktime;
	local int randcheck;
	local bool bDoBlink;
	
	log(self@"entered Timer");

	// Temporary hack to stop talking
	if (bKillTalk)
	{
		log(self@"kill talking somehow");
		// Stop mouth animation
		// We probably ought to stop the animation from playing, but
		// I'm not sure how to do that.
		AnimBlendParams(CHANNEL_MOUTH, 0, 0.1);
		PlayAnim('base', 1.0, 0.0, CHANNEL_MOUTH);
		bKillTalk = false;
	}

	EyeState = BLINKED;
	// Blink eyes and reset timer
	AnimBlendParams(CHANNEL_BLINK, 1);
	PlayAnim('blink', 1.0, 0.0, CHANNEL_BLINK);

	SetTimer(BLINK_TIME, false);
}

defaultproperties
{
     HeadBounce(0)=Sound'MiscSounds.People.head_bounce'
     HeadBounce(1)=Sound'MiscSounds.People.head_bounce2'
     RemoteRole=ROLE_AutonomousProxy
}
