///////////////////////////////////////////////////////////////////////////////
// xCharsHugeRoster
// By: Kamek (kamek@postalleague.com)
// For: xCharacters
//
// An abstract class that contains up to 200 pawn entries.
// Roster can be configured by the server.
///////////////////////////////////////////////////////////////////////////////
class xCharsHugeRoster extends DMRoster
	abstract
	config(xCharacters);
	
///////////////////////////////////////////////////////////////////////////////
// Public vars
///////////////////////////////////////////////////////////////////////////////
var() config array< class<MpPawn> > PawnClasses;

///////////////////////////////////////////////////////////////////////////////
// PostBeginPlay
// Add menu catcher mutator and replicate the dynamic array PawnClasses
///////////////////////////////////////////////////////////////////////////////
simulated event PostBeginPlay()
{
	if (Role == ROLE_Authority)
		Level.Game.AddMutator("xMaDHeAdZChars.MutHugeRoster", false);

	Super.PostBeginPlay();
}

///////////////////////////////////////////////////////////////////////////////
// SendRoster
// Called by MenuCatcher. Hack for replicating the dynamic array PawnClasses
///////////////////////////////////////////////////////////////////////////////
function SendRoster(MenuCatcher MyCatcher)
{
	local int i;

	if (Role == ROLE_Authority)
	{
//		log("Server calling ResetPawnClasses");
		MyCatcher.ClientResetPawnClasses(self);
		for (i=0; i<PawnClasses.Length; i++)
		{
//			log("Server adding pawn of class"@PawnClasses[i]);
			MyCatcher.ClientAddPawnClass(self, PawnClasses[i]);
		}
	}
}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
simulated function class<Pawn> NextLoadOut(class<Pawn> CurrentLoadout)
{
	local int i;
	local class<Pawn> Result;

	Result = PawnClasses[0];

	for ( i=0; i<PawnClasses.Length - 1; i++ )
	{
		if ( PawnClasses[i] == CurrentLoadout )
		{
			if ( PawnClasses[i+1] != None )
				Result = PawnClasses[i+1];
			break;
		}
		else if ( PawnClasses[i] == None )
			break;
	}

	return Result;
}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
simulated function string RandomCharacter()
{
	local int i;
	
	i = rand(PawnClasses.Length);
	return string(PawnClasses[i]);
}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
function bool BelongsOnTeam(class<Pawn> PawnClass)
{
	local int i;

	for ( i=0; i<PawnClasses.Length; i++ )
		if ( PawnClass == PawnClasses[i] )
			return true;

	return false;
}

defaultproperties
{
}
