///////////////////////////////////////////////////////////////////////////////
// xCharsPawn
// By: Kamek (kamek@postalleague.com)
// For: xCharacters
//
// Base class for all xCharacter pawns.
///////////////////////////////////////////////////////////////////////////////
class xCharsPawn extends xMpPawn
	config(xCharacters);

///////////////////////////////////////////////////////////////////////////////
// Structs
///////////////////////////////////////////////////////////////////////////////
// A selectable head
/*
struct HeadInfo
{
	var() config Material HeadTex;		// Head skin
	var() config SkeletalMesh HeadMesh;	// Head mesh
	var() config String Name;			// Name (e.g. "Dude head")
};

// A selectable body
struct BodyInfo
{
	var() config Material BodyTex;		// Body skin
	var() config Texture ArmsTex;		// First person arms
	var() config SkeletalMesh BodyMesh;	// Body mesh
	var() config SkeletalMesh SPMesh;	// Single player mesh
	var() config bool bShortSleeves;	// Short sleeves?
	var() config bool bIsFemale;		// Female?
	var() config class<P2Dialog> DialogClass;	// dialogue class
	var() config String Name;			// Name (e.g. "Dude body")
};
*/
///////////////////////////////////////////////////////////////////////////////
// Consts
///////////////////////////////////////////////////////////////////////////////
const FLIP_BIRD = 'TheFinger';
const DANCING = 'DoDance';
const FEM_PEE_BONE = 'MALE01 pelvis';
var const string DialogVer;

///////////////////////////////////////////////////////////////////////////////
// Public vars
///////////////////////////////////////////////////////////////////////////////
var() MeshAnimation ThisHeadAnim;
var() bool bForceHeadAnim;

/*
var() globalconfig array<HeadInfo> CustomHeads;
var() globalconfig array<BodyInfo> CustomBodies;
var() config HeadInfo DesiredHead;
var() config BodyInfo DesiredBody;
var() bool bAllowCustomSkin;

var() HeadInfo ThisHead;
var() BodyInfo ThisBody;
*/
///////////////////////////////////////////////////////////////////////////////
// Internal
///////////////////////////////////////////////////////////////////////////////
var bool bSetLocalWeapons;
var bool bInitialSetup;
var Controller PlayerLocal;

///////////////////////////////////////////////////////////////////////////////
// Replication block
///////////////////////////////////////////////////////////////////////////////
replication
{
//	reliable if (Role == ROLE_Authority && bNetInitial)
//		ThisHead, ThisBody;

//	reliable if (Role == ROLE_Authority)
//		ClientUpdateSkins;

	reliable if (Role < ROLE_Authority)
		ServerMiddleFinger, ServerDance/*, ServerUpdateSkins*/;
}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
simulated function SetupHead()
{
	Super.SetupHead();

	if (bForceHeadAnim && ThisHeadAnim != None && MyHead != None && Head(MyHead) != None)
	{
		MyHead.LinkSkelAnim(ThisHeadAnim);
		Head(MyHead).SetupAnims();
	}
}

///////////////////////////////////////////////////////////////////////////////
// Female don't have a pee bone
///////////////////////////////////////////////////////////////////////////////
function name GetWeaponBoneFor(Inventory I)
	{
	if(UrethraWeapon(I) != None && bIsFemale)
		return FEM_PEE_BONE;
	else
		return Super.GetWeaponBoneFor(I);
	}


///////////////////////////////////////////////////////////////////////////////
// GetLocalPlayer
// Sets PlayerLocal to the local PlayerController.
///////////////////////////////////////////////////////////////////////////////
simulated function GetLocalPlayer()
{
	local PlayerController C;

	// Don't bother on server side
	if (Level.NetMode != NM_DedicatedServer)
	{
		foreach DynamicActors(class 'PlayerController', C)
    		if (Viewport(C.Player) != None)
    		{
    			PlayerLocal = C;
      			break;
      		}
	}
}
/*
///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
static function SetDesiredSkins(HeadInfo H, BodyInfo B)
{
	log(Default.Class$":: SetDesiredSkins");
	log("Desired head:" @ H.HeadTex @ H.HeadMesh);
	log("Desired body:" @ B.BodyTex @ B.BodyMesh);
	Default.DesiredHead = H;
	Default.DesiredBody = B;
	StaticSaveConfig();
}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
static function HeadInfo GetDesiredHead()
{
	return Default.DesiredHead;
}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
static function BodyInfo GetDesiredBody()
{
	return Default.DesiredBody;
}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
simulated function CheckLocalWeapons()
{
	local Inventory I;
	local class<P2WeaponPickup> PickupClass;
	local Mesh NewMesh;

	if (bShortSleeves)
		log("I am a SHORT SLEEVED pawn");

	for (I=Inventory; I!=None; I=I.Inventory)
	{
		log("Checking inventory"@I);
		if (P2Weapon(I) != None)
		{
			log("Setting hands texture and proper mesh for"@I);

			PickupClass = class<P2WeaponPickup>(I.PickupClass);
			if (PickupClass != None)
			{
				if (bShortSleeves && PickupClass.Default.ShortSleeveType != None)
					NewMesh = PickupClass.Default.ShortSleeveType.Default.Mesh;
				else
					NewMesh = PickupClass.Default.InventoryType.Default.Mesh;

				log("Using weapon mesh:"@NewMesh);

				I.LinkMesh(NewMesh);
			}

			P2Weapon(I).ChangeHandTexture(HandsTexture, DefaultHandsTexture, FootTexture);
		}
		bSetLocalWeapons = True;
	}
}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
simulated function SetHeadAndBodyInfo(HeadInfo H, BodyInfo B)
{
	log(Self$":: SetHeadAndBodyInfo ********");
	log("*** HEAD INFO ***");
	log("Head Skin:" @ H.HeadTex);
	log("Head Mesh:" @ H.HeadMesh);
	log("Head Name:" @ H.Name);
	log("*** BODY INFO ***");
	log("Body Skin:" @ B.BodyTex);
	log("Body Mesh:" @ B.BodyMesh);
	log("Core SP Mesh:" @ B.SPMesh);
	log("Arms Texture:" @ B.ArmsTex);
	log("Short Sleeves:" @ B.bShortSleeves);
	log("Is Female?:" @ B.bIsFemale);
	log("Dialogue Class:" @ B.DialogClass);
	log("Body Name:" @ B.Name);
	log("****************");

	HeadMesh = H.HeadMesh;
	HeadSkin = H.HeadTex;
	CharacterType = CHARACTER_krotchy;

	log("Calling SwitchToNewMesh");
	if (B.SPMesh == None)
	{
		CoreSPMesh = B.BodyMesh;
		SwitchToNewMesh(B.BodyMesh, B.BodyTex, H.HeadMesh, H.HeadTex, B.BodyMesh);
	}
	else
	{
		CoreSPMesh = B.SPMesh;
		SwitchToNewMesh(B.BodyMesh, B.BodyTex, H.HeadMesh, H.HeadTex, B.SPMesh);
	}

	log("Skins[0] =" @ B.BodyTex);
	Skins[0] = B.BodyTex;

	log("HeadSkin =" @ H.HeadTex);
	HeadSkin = H.HeadTex;
	log("HeadMesh =" @ H.HeadMesh);
	HeadMesh = H.HeadMesh;

	if (MyHead != None)
	{
		log(MyHead$".Skins[0] =" @ H.HeadTex);
		MyHead.Skins[0] = H.HeadTex;
	}

	log("HandsTexture =" @ B.ArmsTex);
	HandsTexture = B.ArmsTex;
	if (Texture(B.BodyTex) != None)
	{
		log("FootTexture =" @ B.BodyTex);
		FootTexture = Texture(B.BodyTex);
	}

	log("Setting Core SP Mesh");
	if (B.SPMesh != None)
		CoreSPMesh = B.SPMesh;
	else
		CoreSPMesh = B.BodyMesh;

	log("Setting bShortSleeves" @ B.bShortSleeves @ "and bIsFemale" @ B.bIsFemale);;
	bShortSleeves = B.bShortSleeves;
	bIsFemale = B.bIsFemale;

	if (MyFoot != None)
	{
		log("Setting foot texture");
		MyFoot.ChangeHandTexture(HandsTexture, DefaultHandsTexture, FootTexture);
	}

	if (Level.NetMode != NM_DedicatedServer)
	    CheckLocalWeapons();

	log("***** FINISHED SetHeadAndBodyInfo");
	bInitialSetup = True;
}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
simulated event Tick(float Delta)
{
	Super.Tick(Delta);

	if (Level.NetMode == NM_DedicatedServer || bSetLocalWeapons || !bInitialSetup)
		return;

	if (PlayerLocal != Owner)
	{
		bSetLocalWeapons = True;
		return;
	}

	CheckLocalWeapons();
}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
simulated function ClientUpdateSkins(HeadInfo NewHead, BodyInfo NewBody)
{
	log(Self@"ClientUpdateSkins: Calling SetHeadAndBodyInfo");
	SetHeadAndBodyInfo(NewHead, NewBody);
}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
function ServerUpdateSkins(HeadInfo NewHead, BodyInfo NewBody)
{
	log(Self@"ServerUpdateSkins");
	ThisHead = NewHead;
	ThisBody = NewBody;

	if (Role == ROLE_Authority)
	{
		log("Setting dialog class to" @ ThisBody.DialogClass);
		DialogClass = ThisBody.DialogClass;
		SetupDialog();

		SetHeadAndBodyInfo(NewHead, NewBody);
	}

	ClientUpdateSkins(ThisHead, ThisBody);
}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
simulated event PostNetBeginPlay()
{
	log(self@"PostNetBeginPlay");
	Super.PostNetBeginPlay();

	if (Level.NetMode != NM_DedicatedServer && bAllowCustomSkin && DesiredHead.HeadMesh != None && DesiredBody.BodyMesh != None)
	{
		log("I am a CLIENT and I am using a custom skin -- telling the server about it");
		ServerUpdateSkins(DesiredHead, DesiredBody);
	}
	else if (Role == ROLE_Authority && ThisHead.HeadMesh != None && ThisBody.BodyMesh != None)
	{
		log("I am ROLE_Authority and this pawn has ThisHead and ThisBody set -- telling all clients about it");
		ServerUpdateSkins(ThisHead, ThisBody);
	}

	GetLocalPlayer();
}
*/
///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
simulated function ServerMiddleFinger()
{
	SetAnimAction(FLIP_BIRD);
}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
exec function MiddleFinger()
{
	ServerMiddleFinger();
}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
simulated function ServerDance()
{
	SetAnimAction(DANCING);
}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
exec function Dance()
{
	ServerDance();
}

///////////////////////////////////////////////////////////////////////////////
// xCharsPawn--do dancing
///////////////////////////////////////////////////////////////////////////////
simulated function DoDance()
{
	AnimBlendParams(WEAPONCHANNEL, 1.0, 0,0, BONE_BLENDFIRING);
    PlayAnim('s_dance2', 1.4, 0.1, WEAPONCHANNEL);
	// shout it!
	if(myDialog != None)
		Say(myDialog.lYes);
}

///////////////////////////////////////////////////////////////////////////////
// xCharsPawn--do bird flipping
///////////////////////////////////////////////////////////////////////////////
simulated function DoFlipBird()
{
	AnimBlendParams(WEAPONCHANNEL, 1.0, 0,0, BONE_BLENDFIRING);
    PlayAnim('s_midfinger', 1.4, 0.1, WEAPONCHANNEL);
	// shout it!
	if(myDialog != None)
		Say(myDialog.ldefiantline);
}

///////////////////////////////////////////////////////////////////////////////
// Function that determines how to play all these specific animations.
// Needed complexity to work on remote clients (otherwise only the guy
// on his own machine could see his pawn animating like the following and
// no one elses.)
///////////////////////////////////////////////////////////////////////////////
simulated event SetAnimAction(name NewAction)
{
	AnimAction = NewAction;

	// Pulling pin on grenade to throw it as a weapon
	if ( AnimAction == 'sg_pull_pin' )
	{
		WeaponBlendTime = FIRING_BLEND_TIME;
		AnimBlendParams(WEAPONCHANNEL, 1.0, 0,0, BONE_BLENDFIRING);
		PlayAnim(NewAction, 1.0, 0.1, WEAPONCHANNEL);
	}

	// Grenade suicide
	else if(AnimAction == 's_suicide2')
		PlayAnim('s_suicide2', 1.5, 0.15);

	// third person kicking
	else if(AnimAction == GetAnimKick())
		PlayAnim(GetAnimKick(), 5.0, 0.15);

	// hack for swapping to burned mesh in MP
	else if(AnimAction == BURN_ACTION_MP)
		SwapToBurnVictim();

	// follow me
	else if(AnimAction == FOLLOW_ME)
		DoFollowMe();

	// stay here
	else if(AnimAction == STAY_HERE)
		DoStayHere();

	// flip the bird
	else if(AnimAction == FLIP_BIRD)
		DoFlipBird();

	// dance!
	else if(AnimAction == DANCING)
		DoDance();
}

///////////////////////////////////////////////////////////////////////////////
// Default properties
///////////////////////////////////////////////////////////////////////////////
/*


    ///////////////////////////////////////////////////////////////////////////////
    // Male chameleon heads
	///////////////////////////////////////////////////////////////////////////////
	CustomHeads(0)=(HeadTex=Texture'ChamelHeadSkins.Male.MBA__013__AvgBrotha',HeadMesh=SkeletalMesh'Heads.AvgBrotha',Name="Blk. Male 1")
	CustomHeads(1)=(HeadTex=Texture'ChamelHeadSkins.Male.MBA__014__AvgBrotha',HeadMesh=SkeletalMesh'Heads.AvgBrotha',Name="Blk. Male 2")
	CustomHeads(2)=(HeadTex=Texture'ChamelHeadSkins.Male.MBF__042__FatMale',HeadMesh=SkeletalMesh'Heads.FatMale',Name="Blk. Fat Male 1")
	CustomHeads(3)=(HeadTex=Texture'ChamelHeadSkins.Male.MMA__003__AvgMale',HeadMesh=SkeletalMesh'Heads.AvgMale',Name="Med. Male 1")
	CustomHeads(4)=(HeadTex=Texture'ChamelHeadSkins.Male.MMA__016__AvgMale',HeadMesh=SkeletalMesh'Heads.AvgMale',Name="Med. Male 2")
	CustomHeads(5)=(HeadTex=Texture'ChamelHeadSkins.Male.MMF__024__FatMale',HeadMesh=SkeletalMesh'Heads.FatMale',Name="Med. Fat Male 1")
	CustomHeads(6)=(HeadTex=Texture'ChamelHeadSkins.Male.MWA__001__AvgMale',HeadMesh=SkeletalMesh'Heads.AvgMale',Name="Wht. Male 1")
	CustomHeads(7)=(HeadTex=Texture'ChamelHeadSkins.Male.MWA__002__AvgMale',HeadMesh=SkeletalMesh'Heads.AvgMale',Name="Wht. Male 2")
	CustomHeads(8)=(HeadTex=Texture'ChamelHeadSkins.Male.MWA__004__AvgMale',HeadMesh=SkeletalMesh'Heads.AvgMale',Name="Wht. Male 3")
	CustomHeads(9)=(HeadTex=Texture'ChamelHeadSkins.Male.MWA__005__AvgMale',HeadMesh=SkeletalMesh'Heads.AvgMale',Name="Wht. Male 4")
	CustomHeads(10)=(HeadTex=Texture'ChamelHeadSkins.Male.MWA__006__AvgMale',HeadMesh=SkeletalMesh'Heads.AvgMale',Name="Wht. Male 5")
	CustomHeads(11)=(HeadTex=Texture'ChamelHeadSkins.Male.MWA__007__AvgMale',HeadMesh=SkeletalMesh'Heads.AvgMale',Name="Wht. Male 6")
	CustomHeads(12)=(HeadTex=Texture'ChamelHeadSkins.Male.MWA__008__AvgMale',HeadMesh=SkeletalMesh'Heads.AvgMale',Name="Wht. Male 7")
	CustomHeads(13)=(HeadTex=Texture'ChamelHeadSkins.Male.MWA__009__AvgMale',HeadMesh=SkeletalMesh'Heads.AvgMale',Name="Wht. Male 8")
	CustomHeads(14)=(HeadTex=Texture'ChamelHeadSkins.Male.MWA__010__AvgMale',HeadMesh=SkeletalMesh'Heads.AvgMale',Name="Wht. Male 9")
	CustomHeads(15)=(HeadTex=Texture'ChamelHeadSkins.Male.MWA__011__AvgMale',HeadMesh=SkeletalMesh'Heads.AvgMale',Name="Wht. Male 10")
	CustomHeads(16)=(HeadTex=Texture'ChamelHeadSkins.Male.MWA__015__AvgMale',HeadMesh=SkeletalMesh'Heads.AvgMale',Name="Wht. Male 11")
	CustomHeads(17)=(HeadTex=Texture'ChamelHeadSkins.Male.MWA__035__AvgMale',HeadMesh=SkeletalMesh'Heads.AvgMale',Name="Wht. Male 12")
	CustomHeads(18)=(HeadTex=Texture'ChamelHeadSkins.Male.MWA__021__AvgMaleBig',HeadMesh=SkeletalMesh'Heads.AvgMaleBig',Name="Wht. Big Male 1")
	CustomHeads(19)=(HeadTex=Texture'ChamelHeadSkins.Male.MWA__022__AvgMaleBig',HeadMesh=SkeletalMesh'Heads.AvgMaleBig',Name="Wht. Big Male 2")
	CustomHeads(20)=(HeadTex=Texture'ChamelHeadSkins.Male.MWF__025__FatMale',HeadMesh=SkeletalMesh'Heads.FatMale',Name="Wht. Fat Male 1")

	///////////////////////////////////////////////////////////////////////////////
	// Female chameleon heads
	///////////////////////////////////////////////////////////////////////////////
	CustomHeads(21)=(HeadTex=Texture'ChamelHeadSkins.Female.FBA__033__FemSH',HeadMesh=SkeletalMesh'Heads.FemSH',Name="Blk. Fem. 1")
	CustomHeads(22)=(HeadTex=Texture'ChamelHeadSkins.Female.FBA__063__FemSH',HeadMesh=SkeletalMesh'Heads.FemSH',Name="Blk. Fem. 2")
	CustomHeads(23)=(HeadTex=Texture'ChamelHeadSkins.Female.FBF__043__FatFem',HeadMesh=SkeletalMesh'Heads.FatFem',Name="Blk. Fat Fem. 1")
	CustomHeads(24)=(HeadTex=Texture'ChamelHeadSkins.Female.FMA__028__FemSH',HeadMesh=SkeletalMesh'Heads.FemSH',Name="Med. Fem. 1")
	CustomHeads(25)=(HeadTex=Texture'ChamelHeadSkins.Female.FMA__034__FemSH',HeadMesh=SkeletalMesh'Heads.FemSH',Name="Med. Fem. 2")
	CustomHeads(26)=(HeadTex=Texture'ChamelHeadSkins.Female.FMA__038__FemSHcropped',HeadMesh=SkeletalMesh'Heads.FemSHcropped',Name="Med. Fem. 3")
	CustomHeads(27)=(HeadTex=Texture'ChamelHeadSkins.Female.FMA__039__FemSHcropped',HeadMesh=SkeletalMesh'Heads.FemSHcropped',Name="Med. Fem. 4")
	CustomHeads(28)=(HeadTex=Texture'ChamelHeadSkins.Female.FMF__044__FatFem',HeadMesh=SkeletalMesh'Heads.FatFem',Name="Med. Fat Fem. 1")
	CustomHeads(29)=(HeadTex=Texture'ChamelHeadSkins.Female.FWA__026__FemLH',HeadMesh=SkeletalMesh'Heads.FemLH',Name="Wht. Fem. 1")
	CustomHeads(30)=(HeadTex=Texture'ChamelHeadSkins.Female.FWA__027__FemLH',HeadMesh=SkeletalMesh'Heads.FemLH',Name="Wht. Fem. 2")
	CustomHeads(31)=(HeadTex=Texture'ChamelHeadSkins.Female.FWA__029__FemSH',HeadMesh=SkeletalMesh'Heads.FemSH',Name="Wht. Fem. 3")
	CustomHeads(32)=(HeadTex=Texture'ChamelHeadSkins.Female.FWA__031__FemSH',HeadMesh=SkeletalMesh'Heads.FemSH',Name="Wht. Fem. 4")
	CustomHeads(33)=(HeadTex=Texture'ChamelHeadSkins.Female.FWA__032__FemSH',HeadMesh=SkeletalMesh'Heads.FemSH',Name="Wht. Fem. 5")
	CustomHeads(34)=(HeadTex=Texture'ChamelHeadSkins.Female.FWA__037__FemSHcropped',HeadMesh=SkeletalMesh'Heads.FemSHcropped',Name="Wht. Fem. 6")
	CustomHeads(35)=(HeadTex=Texture'ChamelHeadSkins.Female.FWA__040__FemSHcropped',HeadMesh=SkeletalMesh'Heads.FemSHcropped',Name="Wht. Fem. 7")
	CustomHeads(36)=(HeadTex=Texture'ChamelHeadSkins.Female.FWF__023__FatFem',HeadMesh=SkeletalMesh'Heads.FatFem',Name="Wht. Fat Fem. 1")

	///////////////////////////////////////////////////////////////////////////////
	// Fanatic heads (chameleon and otherwise)
	///////////////////////////////////////////////////////////////////////////////
	CustomHeads(37)=(HeadTex=Texture'ChamelHeadSkins.Fanatic.MFA__018__AvgFanatic',HeadMesh=SkeletalMesh'Heads.AvgFanatic',Name="Al-Qaeda 1")
	CustomHeads(38)=(HeadTex=Texture'ChamelHeadSkins.Fanatic.MFA__019__AvgFanatic',HeadMesh=SkeletalMesh'Heads.AvgFanatic',Name="Al-Qaeda 2")
	CustomHeads(39)=(HeadTex=Texture'ChamelHeadSkins.Fanatic.MFA__020__AvgFanatic',HeadMesh=SkeletalMesh'Heads.AvgFanatic',Name="Al-Qaeda 3")
	CustomHeads(40)=(HeadTex=Texture'zo_tora_height.Meshes.MFA__020__AvgFanatic_BlackT',HeadMesh=SkeletalMesh'Heads.AvgFanatic',Name="Al-Qaeda Red 1")
	CustomHeads(41)=(HeadTex=Texture'zo_tora_height.Meshes.MFA__019__AvgFanatic_BlackT',HeadMesh=SkeletalMesh'Heads.AvgFanatic',Name="Al-Qaeda Red 2")

	///////////////////////////////////////////////////////////////////////////////
	// Special heads
	///////////////////////////////////////////////////////////////////////////////
	CustomHeads(42)=(HeadTex=Texture'ChamelHeadSkins.Special.Dude',HeadMesh=SkeletalMesh'Heads.AvgDude',Name="Dude")
	CustomHeads(43)=(HeadTex=Texture'ChamelHeadSkins.Special.Gary',HeadMesh=SkeletalMesh'Heads.Gary',Name="Gary")
	CustomHeads(44)=(HeadTex=Texture'ChamelHeadSkins.Special.Gimp',HeadMesh=SkeletalMesh'Heads.Masked',Name="Gimp")
	CustomHeads(45)=(HeadTex=Texture'ChamelHeadSkins.Special.Habib',HeadMesh=SkeletalMesh'Heads.AvgMale',Name="Habib")
	CustomHeads(46)=(HeadTex=Texture'ChamelHeadSkins.Special.Kumquat',HeadMesh=SkeletalMesh'Heads.FemSHcropped',Name="Kumquat")
	CustomHeads(47)=(HeadTex=Texture'ChamelHeadSkins.Special.Robber',HeadMesh=SkeletalMesh'Heads.Masked',Name="Robber")
	CustomHeads(48)=(HeadTex=Texture'ChamelHeadSkins.Special.UncleDave',HeadMesh=SkeletalMesh'Heads.AvgMale',Name="Uncle Dave")
	CustomHeads(49)=(HeadTex=Texture'ChamelHeadSkins.Special.Vince',HeadMesh=SkeletalMesh'Heads.AvgMale',Name="RWS Vince")
	CustomHeads(50)=(HeadTex=Texture'xCharsTexFinal.Heads.head_biosnark',HeadMesh=SkeletalMesh'Heads.AvgMale',Name="Biosnark")
	CustomHeads(51)=(HeadTex=Texture'xCharsTexFinal.Heads.head_coachz',HeadMesh=SkeletalMesh'Heads.Masked',Name="Coach Z")
	CustomHeads(52)=(HeadTex=Texture'xCharsTexFinal.Heads.head_dope',HeadMesh=SkeletalMesh'Heads.AvgMale',Name="Dopamine")
	CustomHeads(53)=(HeadTex=Texture'xCharsTexFinal.Heads.head_kamek',HeadMesh=SkeletalMesh'Heads.AvgMale',Name="Kamek")
	CustomHeads(54)=(HeadTex=Texture'xCharsTexFinal.Heads.head_phraud',HeadMesh=SkeletalMesh'xCharacters_Characters.head_phraud',Name="Phraud")
	CustomHeads(54)=(HeadTex=Texture'xCharsTexFinal.Heads.head_reaperx',HeadMesh=SkeletalMesh'Heads.AvgMale',Name="Reaper X")
	CustomHeads(55)=(HeadTex=Texture'xCharsTexFinal.Heads.head_strongbad',HeadMesh=SkeletalMesh'Heads.Masked',Name="Strongbad")

	///////////////////////////////////////////////////////////////////////////////
	// Male chameleon skins
	///////////////////////////////////////////////////////////////////////////////
	CustomBodies(0)=(BodyTex=Texture'ChameleonSkins.BystandersM.MB__015__Avg_M_Jacket_Pants',BodyMesh=SkeletalMesh'MP_Characters.Avg_M_Jacket_Pants',SPMesh=SkeletalMesh'Characters.Avg_M_Jacket_Pants',ArmsTex=Texture'MP_FPArms.LS_arms.LS_hands_bum',Name="Blk. Male 1")
	CustomBodies(1)=(BodyTex=Texture'ChameleonSkins.BystandersM.MB__026__Avg_M_SS_Pants',BodyMesh=SkeletalMesh'MP_Characters.Avg_M_SS_Pants',SPMesh=SkeletalMesh'Characters.Avg_M_SS_Pants',ArmsTex=Texture'xCharsTexFinal.arms.ss_male_gangsterblack',bShortSleeves=True,Name="Blk. Male 2")
	CustomBodies(2)=(BodyTex=Texture'ChameleonSkins.BystandersM.MB__048__Avg_M_SS_Pants',BodyMesh=SkeletalMesh'MP_Characters.Avg_M_SS_Pants',SPMesh=SkeletalMesh'Characters.Avg_M_SS_Pants',ArmsTex=Texture'MP_FPArms.SS_arms.SS_hands_parcelworker',bShortSleeves=True,Name="Blk. Male 3")
	CustomBodies(3)=(BodyTex=Texture'ChameleonSkins.BystandersM.MB__060__Avg_M_SS_Shorts',BodyMesh=SkeletalMesh'MP_Characters.Avg_M_SS_Shorts',SPMesh=SkeletalMesh'Characters.Avg_M_SS_Shorts',ArmsTex=Texture'MP_FPArms.SS_arms.SS_hands_parcelworker',bShortSleeves=True,Name="Blk. Male 4")
	CustomBodies(4)=(BodyTex=Texture'ChameleonSkins.BystandersM.MB__104__Fat_M_SS_Pants',BodyMesh=SkeletalMesh'Characters.Fat_M_SS_Pants',ArmsTex=Texture'MP_FPArms.SS_arms.SS_hands_parcelworker',bShortSleeves=True,Name="Blk. Fat Male 1")
	CustomBodies(5)=(BodyTex=Texture'ChameleonSkins.BystandersM.MM__018__Avg_M_Jacket_Pants',BodyMesh=SkeletalMesh'MP_Characters.Avg_M_Jacket_Pants',SPMesh=SkeletalMesh'Characters.Avg_M_Jacket_Pants',ArmsTex=Texture'MP_FPArms.LS_arms.LS_hands_robber',Name="Med. Male 1")
	CustomBodies(6)=(BodyTex=Texture'ChameleonSkins.BystandersM.MM__027__Avg_M_SS_Pants',BodyMesh=SkeletalMesh'MP_Characters.Avg_M_SS_Pants',SPMesh=SkeletalMesh'Characters.Avg_M_SS_Pants',ArmsTex=Texture'MP_FPArms.SS_arms.SS_hands_uncledave',bShortSleeves=True,Name="Med. Male 2")
	CustomBodies(7)=(BodyTex=Texture'ChameleonSkins.BystandersM.MM__061__Avg_M_SS_Shorts',BodyMesh=SkeletalMesh'MP_Characters.Avg_M_SS_Shorts',SPMesh=SkeletalMesh'Characters.Avg_M_SS_Shorts',ArmsTex=Texture'MP_FPArms.SS_arms.SS_hands_uncledave',bShortSleeves=True,Name="Med. Male 3")
	CustomBodies(8)=(BodyTex=Texture'ChameleonSkins.BystandersM.MM__102__Fat_M_SS_Pants',BodyMesh=SkeletalMesh'Characters.Fat_M_SS_Pants',ArmsTex=Texture'MP_FPArms.SS_arms.SS_hands_uncledave',bShortSleeves=True,Name="Med. Fat Male 1")
	CustomBodies(9)=(BodyTex=Texture'ChameleonSkins.BystandersM.MM__105__Fat_M_SS_Pants',BodyMesh=SkeletalMesh'Characters.Fat_M_SS_Pants',ArmsTex=Texture'MP_FPArms.SS_arms.SS_hands_uncledave',bShortSleeves=True,Name="Med. Fat Male 2")
	CustomBodies(10)=(BodyTex=Texture'ChameleonSkins.BystandersM.MM__107__Fat_M_SS_Pants',BodyMesh=SkeletalMesh'Characters.Fat_M_SS_Pants',ArmsTex=Texture'xCharsTexFinal.arms.ss_junkyardguy',bShortSleeves=True,Name="Med. Fat Male 3")
	CustomBodies(11)=(BodyTex=Texture'ChameleonSkins.BystandersM.MW__016__Avg_M_Jacket_Pants',BodyMesh=SkeletalMesh'MP_Characters.Avg_M_Jacket_Pants',SPMesh=SkeletalMesh'Characters.Avg_M_Jacket_Pants',ArmsTex=Texture'MP_FPArms.LS_arms.LS_hands_robber',Name="Wht. Male 1")
	CustomBodies(12)=(BodyTex=Texture'ChameleonSkins.BystandersM.MW__017__Avg_M_Jacket_Pants',BodyMesh=SkeletalMesh'MP_Characters.Avg_M_Jacket_Pants',SPMesh=SkeletalMesh'Characters.Avg_M_Jacket_Pants',ArmsTex=Texture'MP_FPArms.LS_arms.LS_hands_priest',Name="Wht. Male 2")
	CustomBodies(13)=(BodyTex=Texture'ChameleonSkins.BystandersM.MW__019__Avg_M_Jacket_Pants',BodyMesh=SkeletalMesh'MP_Characters.Avg_M_Jacket_Pants',SPMesh=SkeletalMesh'Characters.Avg_M_Jacket_Pants',ArmsTex=Texture'xCharsTexFinal.arms.ls_jacket_blue',Name="Wht. Male 3")
	CustomBodies(14)=(BodyTex=Texture'ChameleonSkins.BystandersM.MW__021__Avg_M_Jacket_Pants',BodyMesh=SkeletalMesh'MP_Characters.Avg_M_Jacket_Pants',SPMesh=SkeletalMesh'Characters.Avg_M_Jacket_Pants',ArmsTex=Texture'MP_FPArms.LS_arms.LS_hands_robber',Name="Wht. Male 4")
	CustomBodies(15)=(BodyTex=Texture'ChameleonSkins.BystandersM.MW__022__Avg_M_SS_Pants',BodyMesh=SkeletalMesh'MP_Characters.Avg_M_SS_Pants',SPMesh=SkeletalMesh'Characters.Avg_M_SS_Pants',ArmsTex=Texture'MP_FPArms.SS_arms.SS_hands_uncledave',bShortSleeves=True,Name="Wht. Male 5")
	CustomBodies(16)=(BodyTex=Texture'ChameleonSkins.BystandersM.MW__024__Avg_M_SS_Pants',BodyMesh=SkeletalMesh'MP_Characters.Avg_M_SS_Pants',SPMesh=SkeletalMesh'Characters.Avg_M_SS_Pants',ArmsTex=Texture'xCharsTexFinal.arms.ss_tatooed',bShortSleeves=True,Name="Wht. Male 6")
	CustomBodies(17)=(BodyTex=Texture'ChameleonSkins.BystandersM.MW__025__Avg_M_SS_Pants',BodyMesh=SkeletalMesh'MP_Characters.Avg_M_SS_Pants',SPMesh=SkeletalMesh'Characters.Avg_M_SS_Pants',ArmsTex=Texture'MP_FPArms.SS_arms.SS_hands_uncledave',bShortSleeves=True,Name="Wht. Male 7")
	CustomBodies(18)=(BodyTex=Texture'ChameleonSkins.BystandersM.MW__028__Avg_M_SS_Pants',BodyMesh=SkeletalMesh'MP_Characters.Avg_M_SS_Pants',SPMesh=SkeletalMesh'Characters.Avg_M_SS_Pants',ArmsTex=Texture'MP_FPArms.SS_arms.SS_hands_uncledave',bShortSleeves=True,Name="Wht. Male 8")
	CustomBodies(19)=(BodyTex=Texture'ChameleonSkins.BystandersM.MW__062__Avg_M_SS_Shorts',BodyMesh=SkeletalMesh'MP_Characters.Avg_M_SS_Shorts',SPMesh=SkeletalMesh'Characters.Avg_M_SS_Shorts',ArmsTex=Texture'MP_FPArms.SS_arms.SS_hands_uncledave',bShortSleeves=True,Name="Wht. Male 8")
	CustomBodies(20)=(BodyTex=Texture'ChameleonSkins.BystandersM.MW__160__Avg_M_SS_Pants',BodyMesh=SkeletalMesh'MP_Characters.Avg_M_SS_Pants',SPMesh=SkeletalMesh'Characters.Avg_M_SS_Pants',ArmsTex=Texture'MP_FPArms.SS_arms.SS_hands_uncledave',bShortSleeves=True,Name="Wht. Male 9")
	CustomBodies(21)=(BodyTex=Texture'ChameleonSkins.BystandersM.MW__098__Fat_M_Jacket_Pants',BodyMesh=SkeletalMesh'Characters.Fat_M_Jacket_Pants',ArmsTex=Texture'MP_FPArms.LS_arms.LS_hands_priest',Name="Wht. Fat Male 1")
	CustomBodies(22)=(BodyTex=Texture'ChameleonSkins.BystandersM.MW__106__Fat_M_SS_Pants',BodyMesh=SkeletalMesh'Characters.Fat_M_SS_Pants',ArmsTex=Texture'MP_FPArms.SS_arms.SS_hands_uncledave',bShortSleeves=True,Name="Wht. Fat Male 2")
*/

defaultproperties
{
     DialogVer="Final"
     BodyHitSounds(0)=Sound'MiscSounds.People.bodyhitground1'
     BodyHitSounds(1)=Sound'MiscSounds.People.bodyhitground2'
     ChameleonMeshPkgs(0)="Characters"
     ChamelHeadSkins(0)="ChamelHeadSkins.MWA__001__AvgMale"
     ChamelHeadSkins(1)="ChamelHeadSkins.MBA__013__AvgBrotha"
     ChamelHeadSkins(2)="ChamelHeadSkins.MBA__014__AvgBrotha"
     ChamelHeadSkins(3)="ChamelHeadSkins.MMA__016__AvgMale"
     ChamelHeadSkins(4)="ChamelHeadSkins.MMF__024__FatMale"
     ChamelHeadSkins(5)="ChamelHeadSkins.MWA__002__AvgMale"
     ChamelHeadSkins(6)="ChamelHeadSkins.MMA__003__AvgMale"
     ChamelHeadSkins(7)="ChamelHeadSkins.MWA__004__AvgMale"
     ChamelHeadSkins(8)="ChamelHeadSkins.MWA__005__AvgMale"
     ChamelHeadSkins(9)="ChamelHeadSkins.MWA__006__AvgMale"
     ChamelHeadSkins(10)="ChamelHeadSkins.MWA__007__AvgMale"
     ChamelHeadSkins(11)="ChamelHeadSkins.MWA__008__AvgMale"
     ChamelHeadSkins(12)="ChamelHeadSkins.MWA__009__AvgMale"
     ChamelHeadSkins(13)="ChamelHeadSkins.MWA__010__AvgMale"
     ChamelHeadSkins(14)="ChamelHeadSkins.MWA__011__AvgMale"
     ChamelHeadSkins(15)="ChamelHeadSkins.MWA__015__AvgMale"
     ChamelHeadSkins(16)="ChamelHeadSkins.MWA__021__AvgMaleBig"
     ChamelHeadSkins(17)="ChamelHeadSkins.MWA__035__AvgMale"
     ChamelHeadSkins(18)="ChamelHeadSkins.MWF__025__FatMale"
     ChamelHeadSkins(19)="ChamelHeadSkins.MWA__022__AvgMaleBig"
     ChamelHeadSkins(20)="ChamelHeadSkins.FBA__033__FemSH"
     ChamelHeadSkins(21)="ChamelHeadSkins.FMA__028__FemSH"
     ChamelHeadSkins(22)="ChamelHeadSkins.FMA__034__FemSH"
     ChamelHeadSkins(23)="ChamelHeadSkins.FWA__026__FemLH"
     ChamelHeadSkins(24)="ChamelHeadSkins.FWA__027__FemLH"
     ChamelHeadSkins(25)="ChamelHeadSkins.FWA__029__FemSH"
     ChamelHeadSkins(26)="ChamelHeadSkins.FWA__032__FemSH"
     ChamelHeadSkins(27)="ChamelHeadSkins.FWF__023__FatFem"
     ChamelHeadSkins(28)="ChamelHeadSkins.FWA__037__FemSHcropped"
     ChamelHeadSkins(29)="ChamelHeadSkins.FMA__038__FemSHcropped"
     ChamelHeadSkins(30)="ChamelHeadSkins.FMA__039__FemSHcropped"
     ChamelHeadSkins(31)="ChamelHeadSkins.FWA__040__FemSHcropped"
     ChamelHeadSkins(32)="ChamelHeadSkins.MBF__042__FatMale"
     ChamelHeadSkins(33)="ChamelHeadSkins.FBF__043__FatFem"
     ChamelHeadSkins(34)="ChamelHeadSkins.FMF__044__FatFem"
     ChamelHeadSkins(35)="ChamelHeadSkins.FWA__031__FemSH"
     ChamelHeadSkins(36)="ChamelHeadSkins.FBA__063__FemSH"
     ChamelHeadSkins(37)="End"
     ChamelHeadMeshPkgs(0)="heads"
     BaseEquipment(0)=(WeaponClass=Class'Inventory.UrethraWeapon')
     BaseEquipment(1)=(WeaponClass=Class'Inventory.FootWeapon')
     BaseEquipment(2)=(WeaponClass=Class'Inventory.MatchesWeapon')
}
